=====================================
``psyclone.psyir.nodes.profile_node``
=====================================

.. automodule:: psyclone.psyir.nodes.profile_node

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.profile_node


Classes
=======

- :py:class:`ProfileNode`:
  This class can be inserted into a schedule to create profiling code.


.. autoclass:: ProfileNode
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ProfileNode
      :parts: 1
